<?php

namespace Drupal\bootstrap_horizontal_tabs\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\FormatterBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Plugin implementation of the 'bootstrap_horizontal_tabs' formatter.
 *
 * @FieldFormatter(
 *   id = "bootstrap_horizontal_tabs",
 *   label = @Translation("Horizontal Tabs"),
 *   field_types = {
 *     "bootstrap_horizontal_tabs"
 *   }
 * )
 */
class BootstrapHorizontalTabs extends FormatterBase {

  /**
   * {@inheritdoc}
   */
  public static function defaultSettings() {
    return [
      'tab_display' => 'tabs',
    ] + parent::defaultSettings();
  }

  /**
   * {@inheritdoc}
   */
  public function settingsForm(array $form, FormStateInterface $form_state) {
    $elements = parent::settingsForm($form, $form_state);

    $elements['tab_display'] = [
      '#type' => 'select',
      '#title' => $this->t('Header display'),
      '#options' => [
        'tabs' => $this->t('Tabs'),
        'pills' => $this->t('Pill buttons'),
      ],
      '#default_value' => $this->getSetting('tab_display'),
    ];

    return $elements;
  }

  /**
   * {@inheritdoc}
   */
  public function settingsSummary() {
    $summary = [];

    $settings = $this->getSettings();

    if (!empty($settings['tab_display'])) {
      $summary[] = t('Header display: @display', ['@display' => $settings['tab_display']]);
    }

    return $summary;
  }

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {
    if (count($items) == 1) {
      return [
        '#markup' => check_markup($items[0]->body_value, $items[0]->body_format),
      ];
    }
    $settings = $this->getSettings();
    $elements = [
      '#theme' => 'bootstrap_horizontal_tabs',
      '#tab_display' => $settings['tab_display'] ?? 'tabs',
      '#instance_id' => 'a' . substr(md5(uniqid(mt_rand(), TRUE)), 0, 5),
    ];
    foreach ($items as $delta => $item) {
      $elements['#items'][$delta] = [
        'header' => $item->header,
        'body' => check_markup($item->body_value, $item->body_format),
        'id' => preg_replace('/[^a-z0-9_]+/', '_', strtolower($item->header)),
      ];
    }
    return $elements;
  }

}
